@@ -34,6 +34,10 @@
  *          Raph Levien <raph@gimp.org>
  */
 
+#include "config.h"
+#include <math.h>
+#include <string.h>
+
 #include <libgnomecanvas/gnome-canvas.h>
 #include <libgnomecanvas/gnome-canvas-util.h>
 
@@ -109,11 +113,13 @@ static void set_stipple (GdkGC *gc, GdkBitmap **internal_stipple, GdkBitmap *sti
 static void gcbp_ensure_mask (GnomeCanvasShapeExt * bpath, gint width, gint height);
 static void gcbp_draw_ctx_unref (GCBPDrawCtx * ctx);
 static void gnome_canvas_shape_ext_print       (GPrintable *gprintable, GnomePrintContext *pc);
+static void gnome_canvas_shape_ext_export_svg   (GPrintable *gprintable, xmlDocPtr doc, xmlNodePtr node);
 
 static void
 gnome_canvas_shape_ext_print_init (GPrintableIface *iface)
 {
 	iface->print = gnome_canvas_shape_ext_print;
+	iface->export_svg = gnome_canvas_shape_ext_export_svg;
 }
 
 GType
@@ -1635,3 +1641,114 @@ void gnome_canvas_shape_ext_print (GPrintable *printable, GnomePrintContext *pc)
 		gnome_print_stroke (pc);
 	}
 }
+
+static void
+gnome_canvas_shape_ext_export_svg (GPrintable *printable, xmlDocPtr doc, xmlNodePtr node)
+{
+	GnomeCanvasShapeExt *shape;
+	GnomeCanvasShapePriv * priv;
+	GnomeCanvasPathDef * path;
+	gdouble width;
+	ArtBpath * bpath;
+	GString *string;
+	xmlNodePtr child;
+	char *buf;
+	int opacity, i;
+
+	g_return_if_fail (GNOME_IS_CANVAS_SHAPE_EXT (printable));
+	shape = GNOME_CANVAS_SHAPE_EXT (printable);
+	priv = shape->priv;
+	path = priv->path;
+	bpath = gnome_canvas_path_def_bpath	(path);
+
+	child = xmlNewDocNode (doc, NULL, (const xmlChar*) "path", NULL);
+	xmlAddChild (node, child);
+	string = g_string_new ("");
+	for ( ; bpath->code != ART_END ; bpath++)
+		switch (bpath->code) {
+		case ART_MOVETO :
+			g_string_append_printf (string, "M%g %g", bpath->x3, bpath->y3);
+			break;
+		case ART_MOVETO_OPEN :
+			g_string_append_printf (string, "M%g %g", bpath->x3, bpath->y3);
+			break;
+		case ART_LINETO :
+			g_string_append_printf (string, "L%g %g", bpath->x3, bpath->y3);
+			break;
+		default :
+			break;
+		}
+	xmlNewProp (child, (const xmlChar*)"d", (const xmlChar*)string->str);
+	g_string_free (string, TRUE);
+	if (priv->fill_set) {
+		buf = g_strdup_printf ("#%06x", priv->fill_rgba >> 8);
+		xmlNewProp (child, (const xmlChar*)"fill", (const xmlChar*)buf);
+		g_free (buf);
+		opacity = priv->fill_rgba & 0xff;
+		if (opacity != 255) {
+			buf = g_strdup_printf ("%g", (double) opacity / 255.);
+			xmlNewProp (child, (const xmlChar*)"fill-opacity", (const xmlChar*)buf);
+			g_free (buf);
+		}
+	} else
+		xmlNewProp (child, (const xmlChar*)"fill", (const xmlChar*)"none");
+	if (priv->outline_set) {
+		buf = g_strdup_printf ("#%06x", priv->outline_rgba >> 8);
+		xmlNewProp (child, (const xmlChar*)"stroke", (const xmlChar*)buf);
+		g_free (buf);
+		opacity = priv->outline_rgba & 0xff;
+		if (opacity != 255) {
+			buf = g_strdup_printf ("%g", (double) opacity / 255.);
+			xmlNewProp (child, (const xmlChar*)"sroke-opacity", (const xmlChar*)buf);
+			g_free (buf);
+		}
+		if (priv->width_pixels)
+			width = (double) priv->width / shape->item.canvas->pixels_per_unit;
+		else
+			width = priv->width;
+		buf = g_strdup_printf ("%g", width);
+		xmlNewProp (child, (const xmlChar*)"stroke-width", (const xmlChar*)buf);
+		g_free (buf);
+	} else
+		xmlNewProp (child, (const xmlChar*)"stroke", (const xmlChar*)"none");
+
+	switch (priv->cap) {
+	case GDK_CAP_ROUND:
+		xmlNewProp (child, (const xmlChar*)"stroke-linecap", (const xmlChar*)"round");
+		break;
+	case GDK_CAP_PROJECTING:
+		xmlNewProp (child, (const xmlChar*)"stroke-linecap", (const xmlChar*)"square");
+		break;
+	default:
+		xmlNewProp (child, (const xmlChar*)"stroke-linecap", (const xmlChar*)"butt");
+		break;
+	}
+
+	switch (priv->join) {
+	case GDK_JOIN_ROUND:
+		xmlNewProp (child, (const xmlChar*)"stroke-join", (const xmlChar*)"round");
+		break;
+	case GDK_JOIN_BEVEL:
+		xmlNewProp (child, (const xmlChar*)"stroke-linejoin", (const xmlChar*)"bevel");
+		break;
+	default:
+		xmlNewProp (child, (const xmlChar*)"stroke-linejoin", (const xmlChar*)"miter");
+		break;
+	}
+
+	if (priv->dash.n_dash) {
+		char **inc = g_new0 (char*, priv->dash.n_dash + 1);
+		buf = g_strdup_printf ("%g", priv->dash.dash[0]);
+		for (i = 0; i < priv->dash.n_dash; i++)
+			inc[i] = g_strdup_printf ("%g", priv->dash.dash[0]);
+		buf = g_strjoinv (",", inc);
+		for (i = 0; i < priv->dash.n_dash; i++)
+			g_free (inc[i]);
+		g_free (inc);
+		xmlNewProp (child, (const xmlChar*)"stroke-dasharray", (const xmlChar*)buf);
+		g_free (buf);
+		buf = g_strdup_printf ("%g", priv->dash.offset);
+		xmlNewProp (child, (const xmlChar*)"stroke-dashoffset", (const xmlChar*)buf);
+		g_free (buf);
+	}
+}
