@@ -4,9 +4,9 @@
  * GChemPaint
  * cycletool.cc 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -191,6 +191,8 @@ bool gcpCycleTool::OnClicked()
 				switch (i)
 				{
 					case 0:
+						m_x0 = x1;
+						m_y0 = y1;
 						 bDone = false;
 						break;
 					case 1:
@@ -217,8 +219,8 @@ bool gcpCycleTool::OnClicked()
 						orientations.reserve(i);
 						pBond = (gcpBond*)pAtom->GetFirstBond(j);
 						orientations.push_back(pBond->GetAngle2DRad(pAtom));
-						int k;
-						while (pBond = (gcpBond*)pAtom->GetNextBond(j))
+						unsigned k;
+						while ((pBond = (gcpBond*)pAtom->GetNextBond(j)))
 						{
 							k = 0;
 							a0 = pBond->GetAngle2DRad(pAtom);
@@ -305,7 +307,7 @@ void gcpCycleTool::OnDrag()
 			x1 = (m_x - m_xn[0]) * (m_xn[3] - m_xn[1]) + (m_xn[1] - m_y) * (m_xn[2] - m_xn[0]);
 			if (m_nState & GDK_SHIFT_MASK)
 			{
-				if (m_Chain->GetLength() == m_size - 2) return;
+				if (m_Chain->GetLength() == (unsigned) m_size - 2) return;
 				gcpBond* pBond;
 				if (pObject)
 				{
@@ -524,7 +526,6 @@ void gcpCycleTool::OnDrag()
 void gcpCycleTool::OnRelease()
 {
 	if (!m_size) return;
-	double x1, y1, x2, y2;
 	if (m_Chain)
 	{
 		delete m_Chain;
