@@ -4,9 +4,9 @@
  * GChemPaint
  * document.cc 
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -139,16 +139,6 @@ void gcpDocument::SetFileName(const gchar* Name, const gchar* ext)
 	if ((m_pView) && (!IsEmbedded())) m_pView->UpdateLabel(m_label);
 }
 
-/*void gcpDocument::FillCanvas()
-{
-	AnalTree();
-	std::map<std::string, gcpBond*>::iterator j;
-	for (j = m_Bonds.begin(); j != m_Bonds.end(); j++) m_pView->AddBond((*j).second);
-/*	std::map<std::string, gcpAtom*>::iterator i;
-	for (i = m_Atoms.begin(); i != m_Atoms.end(); i++) m_pView->AddAtom((*i).second);
-}*/
-
-
 void gcpDocument::BuildBondList(list<gcpBond*>& BondList, Object* obj)
 {
 	Object* pObject;
@@ -176,7 +166,7 @@ bool gcpDocument::ImportOB(OBMol& Mol)
 	m_title = g_strdup(Mol.GetTitle());
 	OBAtom *atom;
 	gcpAtom* pAtom;
-	double xmin, xmax, ymin, ymax, x, y;
+	double xmin = DBL_MAX, xmax = -DBL_MAX, ymin = DBL_MAX, ymax = -DBL_MAX, x, y;
 	bool valid = false;
 	vector<OBNodeBase*>::iterator i;
 	for (atom = Mol.BeginAtom(i); atom; atom = Mol.NextAtom(i))
@@ -278,7 +268,6 @@ void gcpDocument::ExportOB()
 		Mol.AddAtom(Atom);
 		Atom.Clear();
 	}
-	OBAtom* pAtom;
 	BuildBondList(BondList, this);
 	list<gcpBond*>::iterator j;
 	int start, end, order, flag;
@@ -330,7 +319,6 @@ void gcpDocument::AddAtom(gcpAtom* pAtom)
 	char id[8];
 	const gchar *Id;
 	Id = pAtom->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL) 
 	{
 		id[0] = 'a';
@@ -346,7 +334,6 @@ void gcpDocument::AddAtom(gcpAtom* pAtom)
 		return;
 	}
 	AddObject(pAtom);
-	int i0 = 1;
 	gcpMolecule* mol = new gcpMolecule();
 	i = 1;
 	id[0] = 'm';
@@ -365,7 +352,6 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 	char id[8];
 	const gchar *Id;
 	Id = pFragment->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL) 
 	{
 		id[0] = 'f';
@@ -384,7 +370,6 @@ void gcpDocument::AddFragment(gcpFragment* pFragment)
 	pFragment->AnalContent();
 	if (!pFragment->GetMolecule())
 	{
-		int i0 = 1;
 		gcpMolecule* mol = new gcpMolecule();
 		i = 1;
 		id[0] = 'm';
@@ -404,7 +389,6 @@ void gcpDocument::AddBond(gcpBond* pBond)
 	char id[8];
 	const gchar *Id;
 	Id = pBond->GetId();
-	Object* pObject = GetDescendant(Id);
 	if (Id == NULL)
 	{
 		id[0] = 'b';
@@ -589,7 +573,7 @@ void gcpDocument::ParseXMLTree(xmlDocPtr xml)
 xmlDocPtr gcpDocument::BuildXMLTree()
 {
 	xmlDocPtr xml;
-	xmlNodePtr node;
+	xmlNodePtr node = NULL;
 	char *old_num_locale, *old_time_locale;
 
 	xml = xmlNewDoc((xmlChar*)"1.0");
@@ -684,7 +668,7 @@ void gcpDocument::RemoveAtom(gcpAtom* pAtom)
 {
 	std::map<Atom*, Bond*>::iterator i;
 	gcpBond* pBond;
-	while (pBond = (gcpBond*)pAtom->GetFirstBond(i))
+	while ((pBond = (gcpBond*)pAtom->GetFirstBond(i)))
 	{
 		if (!m_bUndoRedo) m_pCurOp->AddObject(pBond);
 		RemoveBond(pBond);
@@ -700,7 +684,7 @@ void gcpDocument::RemoveFragment(gcpFragment* pFragment)
 	std::map<Atom*, Bond*>::iterator i;
 	gcpAtom* pAtom = pFragment->GetAtom();
 	gcpBond* pBond;
-	while (pBond = (gcpBond*)pAtom->GetFirstBond(i))
+	while ((pBond = (gcpBond*)pAtom->GetFirstBond(i)))
 	{
 		if (!m_bUndoRedo) m_pCurOp->AddObject(pBond);
 		RemoveBond(pBond);
@@ -995,6 +979,7 @@ gcpOperation* gcpDocument::GetNewOperation(gcpOperationType type)
 		case GCP_MODIFY_OPERATION:
 			return m_pCurOp = new gcpModifyOperation(this);
 	}
+	return NULL;
 }
 
 void gcpDocument::AddData(xmlNodePtr node)
