@@ -4,9 +4,9 @@
  * GChemPaint
  * fragment-atom.cc 
  *
- * Copyright (C) 2003
+ * Copyright (C) 2003-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -110,8 +110,7 @@ xmlNodePtr gcpFragmentAtom::Save(xmlDocPtr xml)
 
 bool gcpFragmentAtom::Load(xmlNodePtr node)
 {
-	char* tmp, *endptr;
-	xmlNodePtr child;
+	char* tmp;
 	tmp = (char*)xmlGetProp(node, (xmlChar*)"id");
 	if (tmp)
 	{
