@@ -4,9 +4,9 @@
  * GChemPaint
  * fragmenttool.cc 
  *
- * Copyright (C) 2003
+ * Copyright (C) 2003-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -86,7 +86,6 @@ static void on_get_data(GtkClipboard *clipboard, GtkSelectionData *selection_dat
 
 bool gcpFragmentTool::OnClicked()
 {
-	void *func;
 	if (m_Active && ((m_pObject == NULL) || (m_pObject->GetType() != FragmentType) || (m_Active != m_pData->Items[m_pObject]->item_list->data)))
 	{
 		if (!Unselect()) return false;
