@@ -4,9 +4,9 @@
  * GChemPaint
  * gchempaint-bonobo.cc 
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -217,9 +217,8 @@ gcp_bonobo_control_destroy (BonoboObject *object)
 	g_return_if_fail (GCP_BONOBO_IS_CONTROL (object));
 
 	control = GCP_BONOBO_CONTROL (object);
-	delete control->ps->pDoc;
-	
 	BONOBO_OBJECT_CLASS (gcp_bonobo_control_parent_class)->destroy (object);
+	delete control->ps->pDoc;
 }
 
 static void
@@ -452,7 +451,6 @@ gcpBonoboControl* gcp_bonobo_control_construct(gcpBonoboControl *control, gcpDoc
 {
 	GtkWidget             *widget;
 	BonoboPropertyBag     *pb;
-	BonoboPropertyControl *pc;
 	CORBA_Environment ev;
 	
 	g_return_val_if_fail (pDoc != NULL, NULL);
