@@ -4,9 +4,9 @@
  * GChemPaint
  * selectiontool.cc
  *
- * Copyright (C) 2001-2003
+ * Copyright (C) 2001-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -143,7 +143,6 @@ void gcpSelectionTool::OnRelease()
 		{
 			if (!m_pData->IsSelected((*j).first))
 			{
-				TypeId Id = (*j).first->GetType();
 				gnome_canvas_item_get_bounds(GNOME_CANVAS_ITEM((*j).second), &x0, &y0,&x1, &y1);
 				if ((x0 < m_x1) && (y0 < m_y1) && (x1 > m_x0) && (y1 > m_y0))
 				{
