@@ -4,9 +4,9 @@
  * GChemPaint
  * text.cc 
  *
- * Copyright (C) 2002-2003
+ * Copyright (C) 2002-2005
  *
- * Developed by Jean Bréfort <jean.brefort@ac-dijon.fr>
+ * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -50,7 +50,6 @@ Derivation of a new widget from GnomeCanvasRichTextExt with an event for setting
 */
 static void gnome_canvas_rich_text_gcp_class_init(GnomeCanvasRichTextGCPClass *Class);
 static void gnome_canvas_rich_text_gcp_init(GnomeCanvasRichTextGCP *canvas);
-static GtkWidget *gnome_canvas_rich_text_gcp_new (void);
 
 static void gnome_canvas_rich_text_gcp_realize(GnomeCanvasItem *item);
 static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *event);
@@ -105,11 +104,11 @@ static void gnome_canvas_rich_text_gcp_realize(GnomeCanvasItem *item)
 
 static gint gnome_canvas_rich_text_gcp_event(GnomeCanvasItem *item, GdkEvent *event)
 {
-	GnomeCanvasRichTextExt *text = GNOME_CANVAS_RICH_TEXT_EXT(item);
 	gcpText* pText = (gcpText*)g_object_get_data(G_OBJECT(item), "object");
 	if (pText)
 		if (!pText->OnEvent(event))
 			(* GNOME_CANVAS_ITEM_CLASS(parent_class)->event)(item, event);
+	return false;
 }
 
 gcpText::gcpText(): gcpTextObject(TextType)
@@ -182,7 +181,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 			*iter = *end;
 		}
 		char *rn, *text = gtk_text_buffer_get_text(m_buf, &start, iter, true);
-		while (rn = strchr(text, '\n'))
+		while ((rn = strchr(text, '\n')))
 		{
 			xmlNodeAddContentLen(node, (xmlChar*)text, rn - text);
 			text = rn + 1;
@@ -195,7 +194,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 	{
 		//find the longest included tag
 		TagList0 = TagList;
-		GtkTextTag *tag;
+		GtkTextTag *tag = NULL;
 		while (TagList0)
 		{
 			next = start;
@@ -260,11 +259,13 @@ bool gcpText::Load(xmlNodePtr node)
 	gtk_text_buffer_get_iter_at_offset (m_buf, &iter, 0);
 	while (child)
 	{
-		LoadNode(child, &iter);
+		if (!LoadNode (child, &iter))
+			return false;
 		child = child->next;
 	}
 	m_bLoading = false;
 	OnChanged(m_buf);
+	return true;
 }
 
 bool gcpText::LoadSelection(xmlNodePtr node, GtkTextIter *iter)
@@ -274,11 +275,13 @@ bool gcpText::LoadSelection(xmlNodePtr node, GtkTextIter *iter)
 	child = node->children;
 	while (child)
 	{
-		LoadNode(child, iter);
+		if (!LoadNode (child, iter))
+			return false;
 		child = child->next;
 	}
 	m_bLoading = false;
 	OnChanged(m_buf);
+	return true;
 }
 
 bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
@@ -326,7 +329,7 @@ bool gcpText::LoadNode(xmlNodePtr node, GtkTextIter* CurIter)
 		xmlFree(TagName);
 		return result;
 	}
-	else return false;
+	else return true;
 }
 
 bool gcpText::LoadTaggedNode(xmlNodePtr node, GtkTextIter* CurIter, const char* TagName)
@@ -336,12 +339,13 @@ bool gcpText::LoadTaggedNode(xmlNodePtr node, GtkTextIter* CurIter, const char*
 	xmlNodePtr child = node->children;
 	while (child)
 	{
-		LoadNode(child, CurIter);
+		if (!LoadNode(child, CurIter)) return false;
 		child = child->next;
 	}
 	gtk_text_buffer_get_iter_at_offset(m_buf, &start, offset);
 	gtk_text_buffer_get_selection_bounds(m_buf, NULL, &end);
 	gtk_text_buffer_apply_tag(m_buf, gtk_text_tag_table_lookup(TextTagTable, TagName), &start, &end);
+	return true;
 }
 
 void gcpText::Add(GtkWidget* w)
@@ -598,7 +602,7 @@ void gcpText::SetSelected(GtkWidget* w, int state)
 {
 	gcpWidgetData* pData = (gcpWidgetData*)g_object_get_data(G_OBJECT(w), "data");
 	GnomeCanvasGroup* group = pData->Items[this];
-	gchar* color;
+	gchar* color = NULL;
 	switch (state)
 	{	
 		case SelStateUnselected: color = "white"; break;
