@@ -4,7 +4,7 @@
  * GChemPaint
  * view.cc
  *
- * Copyright (C) 2001-2004
+ * Copyright (C) 2001-2005
  *
  * Developed by Jean Bréfort <jean.brefort@normalesup.org>
  *
@@ -36,6 +36,7 @@
 #include "selectiontool.h"
 #include "libgcpcanvas/gprintable.h"
 #include "libgcpcanvas/gcp-canvas-group.h"
+#include <locale.h>
 #include <math.h>
 #include <pango/pango-context.h>
 #include <libgnomeprint/gnome-print-job.h>
@@ -307,6 +308,8 @@ bool gcpView::OnEvent(GnomeCanvasItem *item, GdkEvent *event, GtkWidget* widget)
 			return true;
 		}
 		break;
+	default:
+		break;
 	}
 	return false;
 }
@@ -718,7 +721,6 @@ bool gcpView::OnSize(int width, int height)
 {
 	if ((width == m_width) && (height == m_height)) return true;
 	std::list<GtkWidget*>::iterator i;
-	int x, y;
 	m_height = height;
 	m_width = width;
 	for (i = m_Widgets.begin(); i != m_Widgets.end(); i++)
@@ -856,7 +858,6 @@ void gcpView::ExportImage (const char* filename, const char* type)
 		xmlFreeDoc (doc);
 	} else {
 		gnome_canvas_update_now (GNOME_CANVAS (m_pWidget));
-		GdkDrawable *drawable = GDK_DRAWABLE (gtk_widget_get_parent_window (m_pWidget));
 		GdkPixbuf *pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, FALSE, 8, w, h);
 		GnomeCanvasBuf buf;
 		buf.buf = gdk_pixbuf_get_pixels (pixbuf);
@@ -873,3 +874,12 @@ void gcpView::ExportImage (const char* filename, const char* type)
 	}
 	m_pData->ShowSelection (true);
 }
+
+void gcpView::EnsureSize ()
+{
+	GnomeCanvas *canvas = GNOME_CANVAS (m_pWidget);
+	while (canvas->idle_id)
+		gtk_main_iteration();
+	gnome_canvas_update_now (canvas);
+	g_signal_emit_by_name (m_pWidget, "update_bounds");
+}
